/*
    FreeRTOS V6.0.5 - Copyright (C) 2010 Real Time Engineers Ltd.

    ***************************************************************************
    *                                                                         *
    * If you are:                                                             *
    *                                                                         *
    *    + New to FreeRTOS,                                                   *
    *    + Wanting to learn FreeRTOS or multitasking in general quickly       *
    *    + Looking for basic training,                                        *
    *    + Wanting to improve your FreeRTOS skills and productivity           *
    *                                                                         *
    * then take a look at the FreeRTOS eBook                                  *
    *                                                                         *
    *        "Using the FreeRTOS Real Time Kernel - a Practical Guide"        *
    *                  http://www.FreeRTOS.org/Documentation                  *
    *                                                                         *
    * A pdf reference manual is also available.  Both are usually delivered   *
    * to your inbox within 20 minutes to two hours when purchased between 8am *
    * and 8pm GMT (although please allow up to 24 hours in case of            *
    * exceptional circumstances).  Thank you for your support!                *
    *                                                                         *
    ***************************************************************************

    This file is part of the FreeRTOS distribution.

    FreeRTOS is free software; you can redistribute it and/or modify it under
    the terms of the GNU General Public License (version 2) as published by the
    Free Software Foundation AND MODIFIED BY the FreeRTOS exception.
    ***NOTE*** The exception to the GPL is included to allow you to distribute
    a combined work that includes FreeRTOS without being obliged to provide the
    source code for proprietary components outside of the FreeRTOS kernel.
    FreeRTOS is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
    more details. You should have received a copy of the GNU General Public 
    License and the FreeRTOS license exception along with FreeRTOS; if not it 
    can be viewed here: http://www.freertos.org/a00114.html and also obtained 
    by writing to Richard Barry, contact details for whom are available on the
    FreeRTOS WEB site.

    1 tab == 4 spaces!

    http://www.FreeRTOS.org - Documentation, latest information, license and
    contact details.

    http://www.SafeRTOS.com - A version that is certified for use in safety
    critical systems.

    http://www.OpenRTOS.com - Commercial support, development, porting,
    licensing and training services.
*/

#ifndef FREERTOS_CONFIG_H
#define FREERTOS_CONFIG_H

#include <hidef.h>
#include "%ProcessorModule.h"

/*-----------------------------------------------------------
 * Application specific definitions.
 *
 * These definitions should be adjusted for your particular hardware and
 * application requirements.
 *
 * THESE PARAMETERS ARE DESCRIBED WITHIN THE 'CONFIGURATION' SECTION OF THE
 * FreeRTOS API DOCUMENTATION AVAILABLE ON THE FreeRTOS.org WEB SITE.
 *
 * See http://www.freertos.org/a00110.html.
 *----------------------------------------------------------*/

%-
%ifdef UsePreemption
#define configUSE_PREEMPTION                                     %>40 1
%else
#define configUSE_PREEMPTION                                     %>40 0
%endif
%ifdef vApplicationIdleHook
#define configUSE_IDLE_HOOK                                      %>40 1
%else
#define configUSE_IDLE_HOOK                                      %>40 0
%endif
%ifdef vApplicationTickHook
#define configUSE_TICK_HOOK                                      %>40 1
%else
#define configUSE_TICK_HOOK                                      %>40 0
%endif
%ifdef vApplicationMallocFailedHook
#define configUSE_MALLOC_FAILED_HOOK                             %>40 1
%else
#define configUSE_MALLOC_FAILED_HOOK                             %>40 0
%endif
#define configCPU_CLOCK_HZ                                       %>40 CPU_BUS_CLK_HZ
#define configTICK_RATE_HZ                                       %>40 ((portTickType)%TickRateHz)
#define configMINIMAL_STACK_SIZE                                 %>40 ((unsigned portSHORT)%MinimalStackSize)
#define configTOTAL_HEAP_SIZE                                    %>40 ((size_t)(%TotalHeapSize))
#define configMAX_TASK_NAME_LEN                                  %>40 %TaskNameLength
%if %UseTraceFacility='yes'
#define configUSE_TRACE_FACILITY                                 %>40 1
%else
#define configUSE_TRACE_FACILITY                                 %>40 0
%endif
%if %Use16bitTicks='yes'
#define configUSE_16_BIT_TICKS                                   %>40 1
%else
#define configUSE_16_BIT_TICKS                                   %>40 0
%endif
%if %IdleShouldYield='yes'
#define configIDLE_SHOULD_YIELD                                  %>40 1
%else
#define configIDLE_SHOULD_YIELD                                  %>40 0
%endif
%if %UseCoroutines='yes'
#define configUSE_CO_ROUTINES                                    %>40 1
%else
#define configUSE_CO_ROUTINES                                    %>40 0
%endif
%if %UseMutexes='yes'
#define configUSE_MUTEXES                                        %>40 1
%else
#define configUSE_MUTEXES                                        %>40 0
%endif
%-
%ifdef vApplicationStackOverflowHook
#define configCHECK_FOR_STACK_OVERFLOW                           %>40 %StackOverflowCheckingMethodNumber
%else
#define configCHECK_FOR_STACK_OVERFLOW                           %>40 0
%endif
%-
%if %UseRecursiveMutexes='yes'
#define configUSE_RECURSIVE_MUTEXES                              %>40 1
%else
#define configUSE_RECURSIVE_MUTEXES                              %>40 0
%endif
%-
#define configQUEUE_REGISTRY_SIZE                                %>40 %QueueRegistrySize
%-
%if %UseCountingSemaphores='yes'
#define configUSE_COUNTING_SEMAPHORES                            %>40 1
%else
#define configUSE_COUNTING_SEMAPHORES                            %>40 0
%endif
%-

#define configMAX_PRIORITIES                                     %>40 ((unsigned portBASE_TYPE)%MaxPriority)
#define configMAX_CO_ROUTINE_PRIORITIES                          %>40 %MaxCoroutinePriorities

/* Set the following definitions to 1 to include the API function, or zero
to exclude the API function. */
%- --------------------------------------------------------------------
%ifdef vTaskPrioritySet
#define INCLUDE_vTaskPrioritySet                                 %>50 1
%else
#define INCLUDE_vTaskPrioritySet                                 %>50 0
%endif  
%- --------------------------------------------------------------------
%ifdef uxTaskPriorityGet
#define INCLUDE_uxTaskPriorityGet                                %>50 1
%else
#define INCLUDE_uxTaskPriorityGet                                %>50 0
%endif
%- --------------------------------------------------------------------
%ifdef vTaskDelete
#define INCLUDE_vTaskDelete                                      %>50 1
%else
#define INCLUDE_vTaskDelete                                      %>50 0
%endif
%- --------------------------------------------------------------------
%if CleanupResources='yes'
#define INCLUDE_vTaskCleanUpResources                            %>50 1
%else
#define INCLUDE_vTaskCleanUpResources                            %>50 0
%endif
%- --------------------------------------------------------------------
%ifdef vTaskSuspend
#define INCLUDE_vTaskSuspend                                     %>50 1
%else
#define INCLUDE_vTaskSuspend                                     %>50 0
%endif
%- --------------------------------------------------------------------
%ifdef vTaskDelayUntil
#define INCLUDE_vTaskDelayUntil                                  %>50 1
%else
#define INCLUDE_vTaskDelayUntil                                  %>50 0
%endif
%- --------------------------------------------------------------------
%ifdef vTaskDelay
#define INCLUDE_vTaskDelay                                       %>50 1
%else
#define INCLUDE_vTaskDelay                                       %>50 0
%endif
%- --------------------------------------------------------------------
%ifdef uxTaskGetStackHighWaterMark
#define INCLUDE_uxTaskGetStackHighWaterMark                      %>50 1
%else
#define INCLUDE_uxTaskGetStackHighWaterMark                      %>50 0
%endif
%- --------------------------------------------------------------------
%ifdef xTaskGetSchedulerState
#define INCLUDE_xTaskGetSchedulerState                           %>50 1
%else
#define INCLUDE_xTaskGetSchedulerState                           %>50 0
%endif
%- --------------------------------------------------------------------

/* It is not advisable to change these values on a ColdFire V1 core. */
#define configKERNEL_INTERRUPT_PRIORITY             %>40 1
#define configMAX_SYSCALL_INTERRUPT_PRIORITY        %>40 7

#if 0 /* not configured yet */
/* Ethernet configuration. */
#define configMAC_0        0x00
#define configMAC_1        0x04
#define configMAC_2        0x9F
#define configMAC_3        0x00
#define configMAC_4        0xAB
#define configMAC_5        0x2B

#define configIP_ADDR0        172
#define configIP_ADDR1        25
#define configIP_ADDR2        218
#define configIP_ADDR3        222

#define configGW_ADDR0        172
#define configGW_ADDR1        25
#define configGW_ADDR2        218
#define configGW_ADDR3        3

#define configNET_MASK0        255
#define configNET_MASK1        255
#define configNET_MASK2        255
#define configNET_MASK3        0

#define configNUM_FEC_RX_BUFFERS           4
#define configFEC_BUFFER_SIZE           1520
#define configUSE_PROMISCUOUS_MODE         0
#define configETHERNET_INPUT_TASK_STACK_SIZE (320)
#define configETHERNET_INPUT_TASK_PRIORITY   (configMAX_PRIORITIES - 1)
#define configPHY_ADDRESS        1

#if (configFEC_BUFFER_SIZE & 0x0F) != 0
  #error configFEC_BUFFER_SIZE must be a multiple of 16.
#endif

#endif

#endif /* FREERTOS_CONFIG_H */
