/*
    FreeRTOS V6.0.5 - Copyright (C) 2010 Real Time Engineers Ltd.

    ***************************************************************************
    *                                                                         *
    * If you are:                                                             *
    *                                                                         *
    *    + New to FreeRTOS,                                                   *
    *    + Wanting to learn FreeRTOS or multitasking in general quickly       *
    *    + Looking for basic training,                                        *
    *    + Wanting to improve your FreeRTOS skills and productivity           *
    *                                                                         *
    * then take a look at the FreeRTOS eBook                                  *
    *                                                                         *
    *        "Using the FreeRTOS Real Time Kernel - a Practical Guide"        *
    *                  http://www.FreeRTOS.org/Documentation                  *
    *                                                                         *
    * A pdf reference manual is also available.  Both are usually delivered   *
    * to your inbox within 20 minutes to two hours when purchased between 8am *
    * and 8pm GMT (although please allow up to 24 hours in case of            *
    * exceptional circumstances).  Thank you for your support!                *
    *                                                                         *
    ***************************************************************************

    This file is part of the FreeRTOS distribution.

    FreeRTOS is free software; you can redistribute it and/or modify it under
    the terms of the GNU General Public License (version 2) as published by the
    Free Software Foundation AND MODIFIED BY the FreeRTOS exception.
    ***NOTE*** The exception to the GPL is included to allow you to distribute
    a combined work that includes FreeRTOS without being obliged to provide the
    source code for proprietary components outside of the FreeRTOS kernel.
    FreeRTOS is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
    more details. You should have received a copy of the GNU General Public 
    License and the FreeRTOS license exception along with FreeRTOS; if not it 
    can be viewed here: http://www.freertos.org/a00114.html and also obtained 
    by writing to Richard Barry, contact details for whom are available on the
    FreeRTOS WEB site.

    1 tab == 4 spaces!

    http://www.FreeRTOS.org - Documentation, latest information, license and
    contact details.

    http://www.SafeRTOS.com - A version that is certified for use in safety
    critical systems.

    http://www.OpenRTOS.com - Commercial support, development, porting,
    licensing and training services.
*/

#ifndef PORTMACRO_H
#define PORTMACRO_H

#ifdef __cplusplus
extern "C" {
#endif

/*-----------------------------------------------------------
 * Port specific definitions.
 *
 * The settings in this file configure FreeRTOS correctly for the
 * given hardware and compiler.
 *
 * These settings should not be altered.
 *-----------------------------------------------------------
 */
%if (COMPILER = "MetrowerksHC08CC") | (COMPILER = "MetrowerksHCS08CC")
/* disabling some warnings as the RTOS sources are not that clean... */
#pragma MESSAGE DISABLE C5909 /* assignment in condition */
#pragma MESSAGE DISABLE C2705 /* possible loss of data */
#pragma MESSAGE DISABLE C5905 /* multiplication with one */
#pragma MESSAGE DISABLE C5904 /* division by one */
#pragma MESSAGE DISABLE C5660 /* removed dead code */
#pragma MESSAGE DISABLE C5917 /* removed dead assignment */
#pragma MESSAGE DISABLE C4001 /* condition always FALSE */
%endif

/* Type definitions. */
%if (CPUfamily = "ColdFireV1")
#define portCHAR               char
#define portFLOAT              float
#define portDOUBLE             double
#define portLONG               long
#define portSHORT              short
#define portSTACK_TYPE         unsigned long
#define portBASE_TYPE          long
%elif (CPUfamily = "HCS08") | (CPUfamily = "HC08")
#define portCHAR               char
#define portFLOAT              float
#define portDOUBLE             double
#define portLONG               long
#define portSHORT              short
#define portSTACK_TYPE         unsigned portCHAR
#define portBASE_TYPE          char
%else
  #error "undefined target"
%endif

#if( configUSE_16_BIT_TICKS == 1 )
  typedef unsigned portSHORT portTickType;
  #define portMAX_DELAY      (portTickType)0xffff
#else
  typedef unsigned portLONG portTickType;
  #define portMAX_DELAY      (portTickType)0xffffffff
#endif
/*-----------------------------------------------------------*/

/* Hardware specifics. */
%if (CPUfamily = "ColdFireV1")
#define portBYTE_ALIGNMENT     4
%elif (CPUfamily = "HCS08") | (CPUfamily = "HC08")
#define portBYTE_ALIGNMENT     1
%else
  #error "undefined target"
%endif
#define portSTACK_GROWTH       -1
#define portTICK_RATE_MS       ((portTickType)1000/configTICK_RATE_HZ)
/*-----------------------------------------------------------*/

unsigned portLONG ulPortSetIPL(unsigned portLONG);

%if (CPUfamily = "ColdFireV1")
#define portDISABLE_INTERRUPTS()        ulPortSetIPL(configMAX_SYSCALL_INTERRUPT_PRIORITY)
#define portENABLE_INTERRUPTS()         ulPortSetIPL(0)
%elif (CPUfamily = "HCS08") | (CPUfamily = "HC08")
#define portENABLE_INTERRUPTS()         __asm("cli")
#define portDISABLE_INTERRUPTS()        __asm("sei")
%endif

%if (CPUfamily = "ColdFireV1")
extern unsigned portLONG uxCriticalNesting;
%elif (CPUfamily = "HCS08") | (CPUfamily = "HC08")
extern volatile unsigned portBASE_TYPE uxCriticalNesting;
%else
  #error "undefined target"
%endif

extern void vPortEnterCritical(void);
extern void vPortExitCritical(void);
#define portENTER_CRITICAL()  vPortEnterCritical()
#define portEXIT_CRITICAL()   vPortExitCritical()

extern unsigned portBASE_TYPE uxPortSetInterruptMaskFromISR(void);
extern void vPortClearInterruptMaskFromISR( unsigned portBASE_TYPE );
#define portSET_INTERRUPT_MASK_FROM_ISR()        ulPortSetIPL(configMAX_SYSCALL_INTERRUPT_PRIORITY)
#define portCLEAR_INTERRUPT_MASK_FROM_ISR(uxSavedStatusRegister) (void)ulPortSetIPL(uxSavedStatusRegister)

/*-----------------------------------------------------------*/

/* Task utilities. */
#define portNOP()        asm volatile ("nop")


/* Context switches are requested using the force register. */
%if (CPUfamily = "ColdFireV1")
#define portCF_INTC_VALUE \
%if FreeRTOSColdFireCPU='MCF51CN' | FreeRTOSColdFireCPU='MCF51JM'
 %if ColdFireSWI='VL1swi'
  0x3E; /* INTC_FRC[LVL1] (VL1swi) set */ \
 %elif ColdFireSWI='VL2swi'
  0x3D; /* INTC_FRC[LVL1] (VL2swi) set */ \
 %elif ColdFireSWI='VL3swi'
  0x3C; /* INTC_FRC[LVL1] (VL3swi) set */ \
 %elif ColdFireSWI='VL4swi'
  0x3B; /* INTC_FRC[LVL1] (VL4swi) set */ \
 %elif ColdFireSWI='VL5swi'
  0x3A; /* INTC_FRC[LVL1] (VL5swi) set */ \
 %elif ColdFireSWI='VL6swi'
  0x39; /* INTC_FRC[LVL1] (VL6swi) set */ \
 %elif ColdFireSWI='VL7swi'
  0x38; /* INTC_FRC[LVL1] (VL7swi) set */ \
 %else
  #error "unknown ColdFireSWI setting in embedded component properties!"
 %endif
%elif FreeRTOSColdFireCPU='MCF51QE'
 %if ColdFireSWI='VL1swi'
  0x26; /* INTC_FRC[LVL1] (VL1swi) set */ \
 %elif ColdFireSWI='VL2swi'
  0x25; /* INTC_FRC[LVL1] (VL2swi) set */ \
 %elif ColdFireSWI='VL3swi'
  0x24; /* INTC_FRC[LVL1] (VL3swi) set */ \
 %elif ColdFireSWI='VL4swi'
  0x23; /* INTC_FRC[LVL1] (VL4swi) set */ \
 %elif ColdFireSWI='VL5swi'
  0x22; /* INTC_FRC[LVL1] (VL5swi) set */ \
 %elif ColdFireSWI='VL6swi'
  0x21; /* INTC_FRC[LVL1] (VL6swi) set */ \
 %elif ColdFireSWI='VL7swi'
  0x20; /* INTC_FRC[LVL1] (VL7swi) set */ \
 %else
  #error "unknown ColdFireSWI setting in embedded component properties!"
 %endif
%else
  #error "unknow ColdFire CPU setting in embedded component properties!"
%endif

#define portYIELD() \
  INTC_SFRC = portCF_INTC_VALUE; /* INTC_FRC[LVLx] (VLxswi) set */ \
  portNOP(); portNOP(); portNOP(); portNOP(); portNOP() /* do some nops to give the machine a chance to raise the interrupt */
%elif (CPUfamily = "HCS08") | (CPUfamily = "HC08")
#define portYIELD()        __asm("swi");
extern byte tempStackHolder1;
extern byte tempStackHolder2;
%else
  #error "unsupported target!"
%endif

/*-----------------------------------------------------------*/

/* Task function macros as described on the FreeRTOS.org WEB site. */
%if (CPUfamily = "ColdFireV1")
#define portTASK_FUNCTION_PROTO(vFunction, pvParameters) \
  void vFunction(void *pvParameters) __attribute__((noreturn))
#define portTASK_FUNCTION(vFunction, pvParameters) \
  void vFunction(void *pvParameters)
%elif (CPUfamily = "HCS08") | (CPUfamily = "HC08")
#define portTASK_FUNCTION_PROTO(vFunction, pvParameters) \
  void vFunction(void *pvParameters)
#define portTASK_FUNCTION(vFunction, pvParameters) \
  void vFunction(void *pvParameters)
%else
  #error "unsupported target!"
%endif
/*-----------------------------------------------------------*/

#define portEND_SWITCHING_ISR(xSwitchRequired) \
  if (xSwitchRequired != pdFALSE) { \
    portYIELD();                    \
  }

%if (CPUfamily = "HCS08") | (CPUfamily = "HC08")
/*
 * These macros are very simple as the processor automatically saves and
 * restores its registers as interrupts are entered and exited.  In
 * addition to the (automatically stacked) registers we also stack the
 * critical nesting count.  Each task maintains its own critical nesting
 * count as it is legitimate for a task to yield from within a critical
 * section.  If the banked memory model is being used then the PPAGE
 * register is also stored as part of the tasks context.
 */

#ifdef BANKED_MODEL
        /*
         * Load the stack pointer for the task, then pull the critical nesting
         * count and PPAGE register from the stack.  The remains of the
         * context are restored by the RTI instruction.
         */
        #define portRESTORE_CONTEXT()    \
        {                                \
                extern volatile void * pxCurrentTCB;  \
                                                                           \
                __asm( "ldx pxCurrentTCB" );                               \
                __asm( "lds 0, x" );                                       \
                __asm( "pula" );                                           \
                __asm( "staa uxCriticalNesting" );                         \
                __asm( "pula" );                                           \
                __asm( "staa 0x30" ); /* 0x30 = PPAGE */                   \
        }

        /*
         * By the time this macro is called the processor has already stacked the
         * registers.  Simply stack the nesting count and PPAGE value, then save
         * the task stack pointer.
         */
        #define portSAVE_CONTEXT()   \
        {                            \
                extern volatile void * pxCurrentTCB;                     \
                                                                         \
                __asm( "ldaa 0x30" );  /* 0x30 = PPAGE */     \
                __asm( "psha" );                              \
                __asm( "ldaa uxCriticalNesting" );            \
                __asm( "psha" );                              \
                __asm( "ldx pxCurrentTCB" );                  \
                __asm( "sts 0, x" );                          \
        }
#else

        /*
         * These macros are as per the BANKED versions above, but without saving
         * and restoring the PPAGE register.
         */
        #define portRESTORE_CONTEXT() { \
                extern volatile void * pxCurrentTCB; \
                __asm( "LDHX pxCurrentTCB" ); \
                __asm( "LDHX 0, X" ); \
                __asm( "TXS" ); \
                __asm( "PULA" ); \
                __asm( "STA uxCriticalNesting" ) \
                __asm( "PULH" ) \
                __asm( "RTI" ); }

        #define portSAVE_CONTEXT() { \
                extern volatile void * pxCurrentTCB; \
                __asm( "LDA uxCriticalNesting" ); \
                __asm( "PSHA" ); \
                __asm( "TSX" ); \
                __asm( "STHX tempStackHolder1"); \
                __asm( "LDHX pxCurrentTCB"); \
                __asm( "LDA tempStackHolder1"); \
                __asm( "STA 0, X"); \
                __asm( "LDA tempStackHolder2"); \
                __asm( "STA 1, X"); }
#endif

/*
 * Utility macro to call macros above in correct order in order to perform a
 * task switch from within a standard ISR.  This macro can only be used if
 * the ISR does not use any local (stack) variables.  If the ISR uses stack
 * variables portYIELD() should be used in it's place.
 */
#define portTASK_SWITCH_FROM_ISR()   \
  portSAVE_CONTEXT();          \
  vTaskSwitchContext();        \
  portRESTORE_CONTEXT();

%endif

void vPortStartFirstTask(void);
  /* starts the first task, called from xPortStartScheduler() */

void vPortYieldHandler(void);

#ifdef __cplusplus
}
#endif

#endif /* PORTMACRO_H */
