/*
    FreeRTOS V6.0.5 - Copyright (C) 2010 Real Time Engineers Ltd.

    ***************************************************************************
    *                                                                         *
    * If you are:                                                             *
    *                                                                         *
    *    + New to FreeRTOS,                                                   *
    *    + Wanting to learn FreeRTOS or multitasking in general quickly       *
    *    + Looking for basic training,                                        *
    *    + Wanting to improve your FreeRTOS skills and productivity           *
    *                                                                         *
    * then take a look at the FreeRTOS eBook                                  *
    *                                                                         *
    *        "Using the FreeRTOS Real Time Kernel - a Practical Guide"        *
    *                  http://www.FreeRTOS.org/Documentation                  *
    *                                                                         *
    * A pdf reference manual is also available.  Both are usually delivered   *
    * to your inbox within 20 minutes to two hours when purchased between 8am *
    * and 8pm GMT (although please allow up to 24 hours in case of            *
    * exceptional circumstances).  Thank you for your support!                *
    *                                                                         *
    ***************************************************************************

    This file is part of the FreeRTOS distribution.

    FreeRTOS is free software; you can redistribute it and/or modify it under
    the terms of the GNU General Public License (version 2) as published by the
    Free Software Foundation AND MODIFIED BY the FreeRTOS exception.
    ***NOTE*** The exception to the GPL is included to allow you to distribute
    a combined work that includes FreeRTOS without being obliged to provide the
    source code for proprietary components outside of the FreeRTOS kernel.
    FreeRTOS is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
    more details. You should have received a copy of the GNU General Public 
    License and the FreeRTOS license exception along with FreeRTOS; if not it 
    can be viewed here: http://www.freertos.org/a00114.html and also obtained 
    by writing to Richard Barry, contact details for whom are available on the
    FreeRTOS WEB site.

    1 tab == 4 spaces!

    http://www.FreeRTOS.org - Documentation, latest information, license and
    contact details.

    http://www.SafeRTOS.com - A version that is certified for use in safety
    critical systems.

    http://www.OpenRTOS.com - Commercial support, development, porting,
    licensing and training services.
*/

/* include inherited beans */
#include "RTOSSWI1.h"
#include "RTOSTMR1.h"

/* Kernel includes. */
#include "FreeRTOS.h"
#include "task.h"

#define portINITIAL_FORMAT_VECTOR                ( ( portSTACK_TYPE ) 0x4000 )

/* Supervisor mode set. */
#define portINITIAL_STATUS_REGISTER                ( ( portSTACK_TYPE ) 0x2000)

/* Used to keep track of the number of nested calls to taskENTER_CRITICAL().  This
will be set to 0 prior to the first task being started. */
volatile unsigned portBASE_TYPE uxCriticalNesting; \


byte tempStackHolder1;
byte tempStackHolder2;
/*-----------------------------------------------------------*/
portSTACK_TYPE *pxPortInitialiseStack( portSTACK_TYPE * pxTopOfStack, pdTASK_CODE pxCode, void *pvParameters ) {
  /*
  Place a few bytes of known values on the bottom of the stack.
  This can be uncommented to provide useful stack markers when debugging.

  *pxTopOfStack = ( portSTACK_TYPE ) 0x11;
  pxTopOfStack--;
  *pxTopOfStack = ( portSTACK_TYPE ) 0x22;
  pxTopOfStack--;
  *pxTopOfStack = ( portSTACK_TYPE ) 0x33;
  pxTopOfStack--;
  */

  /* Setup the initial stack of the task.  The stack is set exactly as
  expected by the portRESTORE_CONTEXT() macro.  In this case the stack as
  expected by the HCS08 RTI instruction.

  When compiling with the -Cs08 options the value of pvParameters needs to show up in the
  H:X registers, but the RTI does not restore H.  We'll push it onto the stack here, and
  later in restoreContext we'll pull it out just before the RTI call.
  */

  /* The address of the task function is placed in the stack byte at a time. */
  *pxTopOfStack = ( portSTACK_TYPE ) *( ((portSTACK_TYPE *) (&pxCode) ) + 1 );
  pxTopOfStack--;
  *pxTopOfStack = ( portSTACK_TYPE ) *( ((portSTACK_TYPE *) (&pxCode) ) + 0 );
  pxTopOfStack--;

  /* Next are all the registers that form part of the task context. */

  /* X register
     We need this even though we pull H:X out of the stack during restore since RTI will overwrite the X reg. */
  *pxTopOfStack = ( portSTACK_TYPE ) *( ((portSTACK_TYPE *) (&pvParameters) ) + 1 );
  pxTopOfStack--;

  /* A register contains parameter high byte. */
  *pxTopOfStack = ( portSTACK_TYPE ) 0xdd;
  pxTopOfStack--;

  /* CCR: Note that when the task starts interrupts will be enabled since "I" bit of CCR is cleared */
  *pxTopOfStack = ( portSTACK_TYPE ) 0x00;
  pxTopOfStack--;

  #ifdef BANKED_MODEL
    /* The page of the task. */
    *pxTopOfStack = ( portSTACK_TYPE ) ( ( int ) pxCode );
    pxTopOfStack--;
  #endif

  /* H register
     This is not part of RTI setup, but we will store the H reg just before the call to RTI. */
  *pxTopOfStack = ( portSTACK_TYPE ) *( ((portSTACK_TYPE *) (&pvParameters) ) + 0 );
  pxTopOfStack--;

  /* Finally the critical nesting depth is initialised with 0 (not within a critical section). */
  *pxTopOfStack = ( portSTACK_TYPE ) 0x00;

  return pxTopOfStack;
}
/*-----------------------------------------------------------*/
#pragma CODE_SEG __NEAR_SEG NON_BANKED
#pragma MESSAGE DISABLE C1404 /* return expected */
#pragma MESSAGE DISABLE C20000 /* dead code detected */
#pragma NO_RETURN
static portBASE_TYPE xBankedStartScheduler(void) {
  /* Restore the context of the first task. */
  portRESTORE_CONTEXT();
  /* Simulate the end of an interrupt to start the scheduler off. */
  __asm( "RTI" );
 /* Should not get here! */
 /* return pdFALSE; */
}
#pragma CODE_SEG DEFAULT
#pragma MESSAGE DEFAULT C1404 /* return expected */
#pragma MESSAGE DEFAULT C20000 /* dead code detected */
/*-----------------------------------------------------------*/
portBASE_TYPE xPortStartScheduler(void) {
  /* xPortStartScheduler() does not start the scheduler directly because
     the header file containing the xPortStartScheduler() prototype is part
     of the common kernel code, and therefore cannot use the CODE_SEG pragma.
     Instead it simply calls the locally defined xBankedStartScheduler() -
     which does use the CODE_SEG pragma. */
  (void)RTOSTMR1_Enable();             /* start the tick timer */
  return xBankedStartScheduler();
}
/*-----------------------------------------------------------*/
void vPortEndScheduler(void) {
  (void)RTOSTMR1_Disable();            /* stop the tick timer */
}
/*-----------------------------------------------------------*/
void vPortEnterCritical(void) {
/*
 * Disable interrupts before incrementing the count of critical section nesting.
 * The nesting count is maintained so we know when interrupts should be
 * re-enabled.  Once interrupts are disabled the nesting count can be accessed
 * directly.  Each task maintains its own nesting count.
 */
  portDISABLE_INTERRUPTS();
  uxCriticalNesting++;
}
/*-----------------------------------------------------------*/
void vPortExitCritical(void) {
 /*
  * Interrupts are disabled so we can access the nesting count directly.  If the
  * nesting is found to be 0 (no nesting) then we are leaving the critical
  * section and interrupts can be re-enabled.
  */
  uxCriticalNesting--;
  if (uxCriticalNesting == 0)  {
    portENABLE_INTERRUPTS();
  }
}
/*-----------------------------------------------------------*/
/*-----------------------------------------------------------*/
void interrupt vPortYieldISR(void) {
  portSAVE_CONTEXT();
  vTaskSwitchContext();
  portRESTORE_CONTEXT();
}
/*-----------------------------------------------------------*/

